@@ -10,7 +10,7 @@ class Kather96x96(H5Dataset):
     Kather dataset, more information can be found at TODO
     """
 
-    def __init__(self, root: str, sub_set: str, transform: Optional[Callable] = None):
+    def __init__(self, root: str, sub_set: str, transform: Optional[Callable] = None, transform_target: Optional[Callable] = None):
         assert sub_set in ['train', 'valid', 'test']
 
         super().__init__(data_path=Path(root) / f'{sub_set}.h5',
@@ -18,11 +18,12 @@ class Kather96x96(H5Dataset):
                          target_path=Path(
                              root) / f'{sub_set}.h5',
                          target_key='label',
-                         transform=transform)
+                         transform=transform,
+                         transform_target=transform_target)
 
     @classmethod
-    def from_avocado(cls, sub_set: str = 'train', transform: Optional[Callable] = None):
-        return cls('/data/ldap/histopathologic/processed_read_only/Kather_96', sub_set, transform)
+    def from_avocado(cls, sub_set: str = 'train', transform: Optional[Callable] = None, transform_target: Optional[Callable] = None):
+        return cls('/data/ldap/histopathologic/processed_read_only/Kather_96', sub_set, transform,transform_target)
 
 
 class Kather224x224(H5Dataset):
@@ -30,7 +31,7 @@ class Kather224x224(H5Dataset):
     Kather dataset, more information can be found at TODO
     """
 
-    def __init__(self, root: str, sub_set: str, transform: Optional[Callable] = None):
+    def __init__(self, root: str, sub_set: str, transform: Optional[Callable] = None, transform_target: Optional[Callable] = None):
         assert sub_set in ['train', 'valid', 'test']
 
         super().__init__(data_path=Path(root) / f'{sub_set}.h5',
@@ -38,8 +39,9 @@ class Kather224x224(H5Dataset):
                          target_path=Path(
                              root) / f'{sub_set}.h5',
                          target_key='label',
-                         transform=transform)
+                         transform=transform,
+                         transform_target=transform_target)
 
     @classmethod
-    def from_avocado(cls, sub_set: str = 'train', transform: Optional[Callable] = None):
-        return cls('/data/ldap/histopathologic/processed_read_only/Kather_224', sub_set, transform)
\ No newline at end of file
+    def from_avocado(cls, sub_set: str = 'train', transform: Optional[Callable] = None, transform_target: Optional[Callable] = None):
+        return cls('/data/ldap/histopathologic/processed_read_only/Kather_224', sub_set, transform, transform_target)
\ No newline at end of file
